#include "Widget.h"

#include <QComboBox>
#include <QFile>
#include <QResource>
#include <QAbstractItemView>
#include <QPushButton>
#include <QGridLayout>

Widget::Widget(QWidget *parent)
    : QWidget(parent)
    , m_cb( 0 )
    , m_add( 0 )
    , m_remove( 0 )
    , m_set5( 0 )
    , m_set10( 0 )
    , m_set100( 0 )
    , m_i( -1 )
{
    m_cb = new QComboBox( this );
    m_cb->setObjectName( "combo" );

    QGridLayout* layout = new QGridLayout( this );
    layout->addWidget( m_cb, 0, 0 );

    m_add = new QPushButton( "Add" );
    layout->addWidget( m_add, 1, 1 );

    m_remove = new QPushButton( "Remove" );
    layout->addWidget( m_remove, 0, 1 );

    m_clear = new QPushButton( "Clear" );
    layout->addWidget( m_clear, 0, 2 );

    m_set5 = new QPushButton( "Set 5" );
    layout->addWidget( m_set5, 1, 2 );

    m_set10 = new QPushButton( "Set 10" );
    layout->addWidget( m_set10, 1, 3 );

    m_set100 = new QPushButton( "Set 100" );
    layout->addWidget( m_set100, 1, 4 );

    m_remove->setEnabled( false );
    m_clear->setEnabled( false );

    connect( m_add, SIGNAL(clicked()), this, SLOT(onAdd()) );
    connect( m_remove, SIGNAL(clicked()), this, SLOT(onRemove()) );
    connect( m_clear, SIGNAL(clicked()), this, SLOT(onClear()) );
    connect( m_set5, SIGNAL(clicked()), this, SLOT(onSet5()) );
    connect( m_set10, SIGNAL(clicked()), this, SLOT(onSet10()) );
    connect( m_set100, SIGNAL(clicked()), this, SLOT(onSet100()) );
}

Widget::~Widget()
{
}

void Widget::onAdd()
{
    if ( ! m_remove->isEnabled() )
    {
        m_remove->setEnabled( true );
        m_clear->setEnabled( true );
    }

    m_cb->addItem( QString::number( ++ m_i ) );
    m_cb->setCurrentIndex( m_cb->count() - 1 );
}

void Widget::onRemove()
{
    if ( m_i >= 0 )
    {
        m_cb->removeItem( m_cb->count() - 1 );

        if ( m_i == 0 )
        {
            m_remove->setEnabled( false );
            m_clear->setEnabled( false );
        }
        else
        {
            m_cb->setCurrentIndex( m_cb->count() - 1 );
        }

        -- m_i;
    }
}

void Widget::onClear()
{
    m_cb->clear();
    m_i = -1;
    m_remove->setEnabled( false );
    m_clear->setEnabled( false );
}

void Widget::onSet5()
{
    this->onClear();
    this->modifyN( 5, true );
}

void Widget::onSet10()
{
    this->onClear();
    this->modifyN( 10, true );
}

void Widget::onSet100()
{
    this->onClear();
    this->modifyN( 100, true );
}

void Widget::modifyN( int n, bool addOrRemove )
{
    for( int i = 0; i < n; ++i )
    {
        addOrRemove ? this->onAdd() : this->onRemove();
    }
}
